@@ -61,7 +61,7 @@ namespace Kwave
 	            ogg_packet &op);
 
 	/** destructor */
-	virtual ~OpusDecoder() {}
+        virtual ~OpusDecoder() Q_DECL_OVERRIDE {}
 
 	/**
 	 * parse the header of the stream and initialize the decoder
@@ -69,23 +69,23 @@ namespace Kwave
 	 * @param info reference to a FileInfo to fill
 	 * @return -1 if failed or +1 if succeeded
 	 */
-	int open(QWidget *widget, Kwave::FileInfo &info) Q_DECL_OVERRIDE;
+        virtual int open(QWidget *widget, Kwave::FileInfo &info) Q_DECL_OVERRIDE;
 
 	/**
 	 * decode received ogg data
 	 * @param dst a MultiWriter to be used as sink
 	 * @return -1 if failed or >= 0 if succeeded
 	 */
-	int decode(Kwave::MultiWriter &dst) Q_DECL_OVERRIDE;
+        virtual int decode(Kwave::MultiWriter &dst) Q_DECL_OVERRIDE;
 
 	/** reset the stream info */
-	void reset() Q_DECL_OVERRIDE;
+        virtual void reset() Q_DECL_OVERRIDE;
 
 	/**
 	 * finish the decoding, last chance to fix up some file info
 	 * @param info reference to a FileInfo to fill
 	 */
-	void close(Kwave::FileInfo &info) Q_DECL_OVERRIDE;
+        virtual void close(Kwave::FileInfo &info) Q_DECL_OVERRIDE;
 
     protected:
 
