@@ -16,8 +16,10 @@
  ***************************************************************************/
 
 #include "config.h"
+
 #include <errno.h>
 #include <math.h>
+#include <new>
 
 #include <KLocalizedString>
 #include <QString>
@@ -59,15 +61,15 @@ QStringList *Kwave::SelectRangePlugin::setup(QStringList &previous_params)
     sample_index_t offset = manager().selectionStart();
     sample_index_t length = signalLength();
 
-    Kwave::SelectRangeDialog *dialog =
-	new Kwave::SelectRangeDialog(parentWidget(),
+    QPointer<Kwave::SelectRangeDialog> dialog =
+	new(std::nothrow) Kwave::SelectRangeDialog(parentWidget(),
 	    m_start_mode, m_range_mode, m_range, rate, offset, length);
     Q_ASSERT(dialog);
     if (!dialog) return Q_NULLPTR;
 
-    QStringList *list = new QStringList();
+    QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
-    if (list && dialog->exec()) {
+    if (list && dialog->exec() && dialog) {
 	// user has pressed "OK"
 	*list << QString::number(dialog->startMode());
 	*list << QString::number(dialog->rangeMode());
